==> webpdf-wsclient-2.0.2-sources.jar: net/webpdf/wsclient/schema/operation/OptionsMarginType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for OptionsMarginType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OptionsMarginType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="left" default="0"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}float"&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="right" default="0"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}float"&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="top" default="0"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}float"&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="bottom" default="0"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}float"&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="metrics" type="{http://schema.webpdf.de/1.0/operation}MetricsType" default="mm" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OptionsMarginType")
public class OptionsMarginType {

    @XmlAttribute(name = "left")
    protected Float left;
    @XmlAttribute(name = "right")
    protected Float right;
    @XmlAttribute(name = "top")
    protected Float top;
    @XmlAttribute(name = "bottom")
    protected Float bottom;
    @XmlAttribute(name = "metrics")
    protected MetricsType metrics;

    /**
     * Gets the value of the left property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getLeft() {
        if (left == null) {
            return  0.0F;
        } else {
            return left;
        }
    }

    /**
     * Sets the value of the left property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setLeft(float value) {
        this.left = value;
    }

    public boolean isSetLeft() {
        return (this.left!= null);
    }

    public void unsetLeft() {
        this.left = null;
    }

    /**
     * Gets the value of the right property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getRight() {
        if (right == null) {
            return  0.0F;
        } else {
            return right;
        }
    }

    /**
     * Sets the value of the right property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setRight(float value) {
        this.right = value;
    }

    public boolean isSetRight() {
        return (this.right!= null);
    }

    public void unsetRight() {
        this.right = null;
    }

    /**
     * Gets the value of the top property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getTop() {
        if (top == null) {
            return  0.0F;
        } else {
            return top;
        }
    }

    /**
     * Sets the value of the top property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setTop(float value) {
        this.top = value;
    }

    public boolean isSetTop() {
        return (this.top!= null);
    }

    public void unsetTop() {
        this.top = null;
    }

    /**
     * Gets the value of the bottom property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getBottom() {
        if (bottom == null) {
            return  0.0F;
        } else {
            return bottom;
        }
    }

    /**
     * Sets the value of the bottom property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setBottom(float value) {
        this.bottom = value;
    }

    public boolean isSetBottom() {
        return (this.bottom!= null);
    }

    public void unsetBottom() {
        this.bottom = null;
    }

    /**
     * Gets the value of the metrics property.
     * 
     * @return
     *     possible object is
     *     {@link MetricsType }
     *     
     */
    public MetricsType getMetrics() {
        if (metrics == null) {
            return MetricsType.MM;
        } else {
            return metrics;
        }
    }

    /**
     * Sets the value of the metrics property.
     * 
     * @param value
     *     allowed object is
     *     {@link MetricsType }
     *     
     */
    public void setMetrics(MetricsType value) {
        this.metrics = value;
    }

    public boolean isSetMetrics() {
        return (this.metrics!= null);
    }

}

==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/OptionsMarginType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p34504_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:p624220_="https://jakarta.ee/xml/ns/jaxb" xmlns:p996221_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Defines the outer offsets between an inner element and an outer element.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for OptionsMarginType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="OptionsMarginType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="left" default="0">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}float">
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="right" default="0">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}float">
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="top" default="0">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}float">
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="bottom" default="0">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}float">
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="metrics" type="{http://schema.webpdf.de/1.0/operation}MetricsType" default="mm" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OptionsMarginType")
public class OptionsMarginType {

    @XmlAttribute(name = "left")
    protected Float left;
    @XmlAttribute(name = "right")
    protected Float right;
    @XmlAttribute(name = "top")
    protected Float top;
    @XmlAttribute(name = "bottom")
    protected Float bottom;
    @XmlAttribute(name = "metrics")
    protected MetricsType metrics;

    /**
     * Gets the value of the left property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getLeft() {
        if (left == null) {
            return  0.0F;
        } else {
            return left;
        }
    }

    /**
     * Sets the value of the left property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setLeft(float value) {
        this.left = value;
    }

    public boolean isSetLeft() {
        return (this.left!= null);
    }

    public void unsetLeft() {
        this.left = null;
    }

    /**
     * Gets the value of the right property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getRight() {
        if (right == null) {
            return  0.0F;
        } else {
            return right;
        }
    }

    /**
     * Sets the value of the right property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setRight(float value) {
        this.right = value;
    }

    public boolean isSetRight() {
        return (this.right!= null);
    }

    public void unsetRight() {
        this.right = null;
    }

    /**
     * Gets the value of the top property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getTop() {
        if (top == null) {
            return  0.0F;
        } else {
            return top;
        }
    }

    /**
     * Sets the value of the top property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setTop(float value) {
        this.top = value;
    }

    public boolean isSetTop() {
        return (this.top!= null);
    }

    public void unsetTop() {
        this.top = null;
    }

    /**
     * Gets the value of the bottom property.
     * 
     * @return
     *     possible object is
     *     {@link Float }
     *     
     */
    public float getBottom() {
        if (bottom == null) {
            return  0.0F;
        } else {
            return bottom;
        }
    }

    /**
     * Sets the value of the bottom property.
     * 
     * @param value
     *     allowed object is
     *     {@link Float }
     *     
     */
    public void setBottom(float value) {
        this.bottom = value;
    }

    public boolean isSetBottom() {
        return (this.bottom!= null);
    }

    public void unsetBottom() {
        this.bottom = null;
    }

    /**
     * Gets the value of the metrics property.
     * 
     * @return
     *     possible object is
     *     {@link MetricsType }
     *     
     */
    public MetricsType getMetrics() {
        if (metrics == null) {
            return MetricsType.MM;
        } else {
            return metrics;
        }
    }

    /**
     * Sets the value of the metrics property.
     * 
     * @param value
     *     allowed object is
     *     {@link MetricsType }
     *     
     */
    public void setMetrics(MetricsType value) {
        this.metrics = value;
    }

    public boolean isSetMetrics() {
        return (this.metrics!= null);
    }

}
